/*
 *  Crystality Plugin - A plugin for remastering mp3 sound in realtime
 *
 *	Copyright (C) 2002 Alex Lagutin <alex@subband.com>
 *  Copyright (C) 2001 Rafal Bosak <gyver@fanthom.irc.pl>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#import "CrystalityController.h"
#import "com.subband.crystality.h"

#define	MY_UID	@COM_SUBBAND_CRYSTALITY_UID

@implementation CrystalityController

- (id)initWithChannel:(id <MSSChannelPluginControl>)channel;
{
	[super init];
	mChan	= channel;
    return self;
}

- (NSView *)view
{
	[NSBundle loadNibNamed:@"CrystalityController" owner:self];
	return mView;
}

- (IBAction)SetBextLevel:(id)sender
{
	float	fval = [sender floatValue];
	[mChan setData:&fval forPlugin:MY_UID andControl:kCrystalityBextLevel];
	[bextLevelCaption setStringValue:[NSString stringWithFormat:@"%.1f", fval]];
}

- (IBAction)SetFilterLevel:(id)sender
{
	int	ival = [sender intValue];
	[mChan setData:&ival forPlugin:MY_UID andControl:kCrystalityFilterLevel];
}

- (IBAction)SetEchoLevel:(id)sender
{
	float	fval = [sender floatValue];
	[mChan setData:&fval forPlugin:MY_UID andControl:kCrystalityEchoLevel];
	[echoLevelCaption setStringValue:[NSString stringWithFormat:@"%.1f", fval]];
}

- (IBAction)SetStereoLevel:(id)sender
{
	float	fval = [sender floatValue];
	[mChan setData:&fval forPlugin:MY_UID andControl:kCrystalityStereoLevel];
	[stereoLevelCaption setStringValue:[NSString stringWithFormat:@"%.1f", fval]];
}

- (IBAction)SetFeedbackLevel:(id)sender
{
	float	fval = [sender floatValue];
	[mChan setData:&fval forPlugin:MY_UID andControl:kCrystalityFeedbackLevel];
	[feedbackLevelCaption setStringValue:[NSString stringWithFormat:@"%.1f", fval]];
}

- (IBAction)SetHarmonicsLevel:(id)sender
{
	float	fval = [sender floatValue];
	[mChan setData:&fval forPlugin:MY_UID andControl:kCrystalityHarmonicsLevel];
	[harmonicsLevelCaption setStringValue:[NSString stringWithFormat:@"%.1f", fval]];
}

- (IBAction)Enable3DEcho:(id)sender
{
	int	ival = [sender intValue];
	
	[mChan setData:&ival forPlugin:MY_UID andControl:kCrystality3DEchoEnabled];
}

- (IBAction)EnableBext:(id)sender
{
	int	ival = [sender intValue];
	
	[mChan setData:&ival forPlugin:MY_UID andControl:kCrystalityBextEnabled];
}

- (IBAction)SetDefaults:(id)sender
{
	[mChan setData:NULL forPlugin:MY_UID andControl:kCrystalitySetDefaults];
	[self willDisplayView];
}

- (void)willDisplayView
{
	int		ival;
	float	fval;
	
	[mChan getData:&ival forPlugin:MY_UID andControl:kCrystalityFilterLevel];
	[filterLevelSlider setIntValue:ival];

	[mChan getData:&fval forPlugin:MY_UID andControl:kCrystalityBextLevel];
	[bextLevelSlider setFloatValue:fval];
	[bextLevelCaption setStringValue:[NSString stringWithFormat:@"%.1f", fval]];

	[mChan getData:&fval forPlugin:MY_UID andControl:kCrystalityEchoLevel];
	[echoLevelSlider setFloatValue:fval];
	[echoLevelCaption setStringValue:[NSString stringWithFormat:@"%.1f", fval]];

	[mChan getData:&fval forPlugin:MY_UID andControl:kCrystalityStereoLevel];
	[stereoLevelSlider setFloatValue:fval];
	[stereoLevelCaption setStringValue:[NSString stringWithFormat:@"%.1f", fval]];

	[mChan getData:&fval forPlugin:MY_UID andControl:kCrystalityFeedbackLevel];
	[feedbackLevelSlider setFloatValue:fval];
	[feedbackLevelCaption setStringValue:[NSString stringWithFormat:@"%.1f", fval]];

	[mChan getData:&fval forPlugin:MY_UID andControl:kCrystalityHarmonicsLevel];
	[harmonicsLevelSlider setFloatValue:fval];
	[harmonicsLevelCaption setStringValue:[NSString stringWithFormat:@"%.1f", fval]];

	[mChan getData:&ival forPlugin:MY_UID andControl:kCrystality3DEchoEnabled];	
	[echo3DEnabledCheckbox setState:(ival ? NSOnState : NSOffState)];

	[mChan getData:&ival forPlugin:MY_UID andControl:kCrystalityBextEnabled];	
	[bextEnabledCheckbox setState:(ival ? NSOnState : NSOffState)];
}

- (void)willDetachView
{

}

- (void)willAttachView
{

}

//awakeFromNib is called when this object is done being unpacked from the nib file;
//at this point, we can do any needed initialization before turning app control over to the user
- (void)awakeFromNib
{
	[self willDisplayView];
}

@end
